.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/

|

=======================
requests-kerberos-proxy
=======================


    An front end to requests in order to use Kerberos behind a proxy


This package provides a work around in order to deal with a proxy if you want to use kerberos


.. _pyscaffold-notes:

Note
====

This project has been set up using PyScaffold 4.5. For details and usage
information on PyScaffold see https://pyscaffold.org/.
